@@ -5,10 +5,9 @@ import gettext
 import gobject
 import gtk
 from .widget import Widget, TranslateMixin
-from tryton.common import Tooltips
+from tryton.common import Tooltips, IconFactory
 from tryton.common.entry_position import reset_position
 from tryton.common.selection import PopdownMixin, selection_shortcuts
-from tryton.common.widget_style import set_widget_style
 from tryton.config import CONFIG
 
 _ = gettext.gettext
@@ -47,8 +46,9 @@ class Char(Widget, TranslateMixin, PopdownMixin):
         self.widget.pack_start(self.entry, expand=expand, fill=fill)
 
         if attrs.get('translate'):
-            self.entry.set_icon_from_stock(gtk.ENTRY_ICON_SECONDARY,
-                'tryton-locale')
+            self.entry.set_icon_from_pixbuf(
+                gtk.ENTRY_ICON_SECONDARY,
+                IconFactory.get_pixbuf('tryton-translate', gtk.ICON_SIZE_MENU))
             self.entry.connect('icon-press', self.translate)
 
     def translate_widget(self):
@@ -60,17 +60,14 @@ class Char(Widget, TranslateMixin, PopdownMixin):
             entry.set_max_length(field_size or 0)
         return entry
 
-    @staticmethod
-    def translate_widget_set(widget, value):
+    def translate_widget_set(self, widget, value):
         widget.set_text(value or '')
         reset_position(widget)
 
-    @staticmethod
-    def translate_widget_get(widget):
+    def translate_widget_get(self, widget):
         return widget.get_text()
 
-    @staticmethod
-    def translate_widget_set_readonly(widget, value):
+    def translate_widget_set_readonly(self, widget, value):
         widget.set_editable(not value)
         widget.props.sensitive = not value
 
@@ -155,7 +152,6 @@ class Char(Widget, TranslateMixin, PopdownMixin):
         else:
             entry_editable = self.entry
         entry_editable.set_editable(not value)
-        set_widget_style(entry_editable, not value)
         if value and CONFIG['client.fast_tabbing']:
             self.widget.set_focus_chain([])
         else:
